==> org-lsst-ccs-command-1.0-sources.jar: org/lsst/ccs/command/DictionaryParameter.java <==
package org.lsst.ccs.command;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * Encapsulate the dictionary information about a single parameter.
 * If the parameter is an Enum, we capture the list of legal values (we
 * do not want to require that the Enum class itself be available in a remote 
 * client).
 * @author turri
 */
public class DictionaryParameter implements Serializable {
    
    private String name;
    private String description;
    private String type;
    private String[] values;

    
    DictionaryParameter(String name, Class type, String description) {
        this.name = name;
        this.type = type.getSimpleName();
        if (type.isEnum()) {
            Enum[] enums = ((Class<? extends Enum>) type).getEnumConstants();
            values = new String[enums.length];
            for (int i=0; i<enums.length; i++) {
                values[i] = enums[i].name();
            }
        }
        this.description = description;
    }
    
    public String getName() {
        return name;
    }

    public String getType() {
        return type;
    }

    public String getDescription() {
        return description;
    }

    public List<String> getValues() {
        return values == null ? Collections.<String>emptyList() : Collections.unmodifiableList(Arrays.asList(values));
    }
    
    String getDefaultValue() {
        //FIXME: Not implemented yet
        throw new UnsupportedOperationException("Not supported yet."); //To change body of generated methods, choose Tools | Templates.
    }
}

==> org-lsst-ccs-command-1.2-sources.jar: org/lsst/ccs/command/DictionaryParameter.java <==
package org.lsst.ccs.command;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * Encapsulate the dictionary information about a single argument.
 * If the parameter is an Enum, we capture the list of legal values (we
 * do not want to require that the Enum class itself be available in a remote 
 * client).
 * @author turri
 */
public class DictionaryParameter implements Serializable {
    
    private String name;
    private String description;
    private String type;
    private String simpleType;
    private String[] values;

    
    DictionaryParameter(String name, Class type, String description) {
        this.name = name;
        this.type = type.getCanonicalName();
        this.simpleType = type.getSimpleName();
        if (type.isEnum()) {
            Enum[] enums = ((Class<? extends Enum>) type).getEnumConstants();
            values = new String[enums.length];
            for (int i=0; i<enums.length; i++) {
                values[i] = enums[i].name();
            }
        }
        this.description = description;
    }
    
    public String getName() {
        return name;
    }

    /**
     * Get the type of this parameter
     * @return The full canonical type (e.g. java.lang.String)
     */
    public String getType() {
        return type;
    }
    
    /**
     * Get the simple type of this parameter
     * @return The full canonical type (e.g. String)
     */
    public String getSimpleType() {
        return simpleType;
    }

    public String getDescription() {
        return description;
    }

    public List<String> getValues() {
        return values == null ? Collections.<String>emptyList() : Collections.unmodifiableList(Arrays.asList(values));
    }
    
    String getDefaultValue() {
        //FIXME: Not implemented yet
        throw new UnsupportedOperationException("Not supported yet."); //To change body of generated methods, choose Tools | Templates.
    }
}
